# Generated by Django 5.1 on 2024-09-30 12:34

import ckeditor_uploader.fields
import django.db.models.deletion
from django.db import migrations, models

import sendmail.models
import sendmail.models.attachment
import sendmail.validators


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DBMutex',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('lock_id', models.CharField(max_length=50, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('expires_at', models.DateTimeField()),
                ('locked_by', models.UUIDField(db_index=True)),
            ],
        ),
        migrations.CreateModel(
            name='EmailAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.CharField(max_length=254, unique=True, validators=[sendmail.validators.validate_email_with_name], verbose_name='Email From')),
                ('first_name', models.CharField(blank=True, max_length=254, null=True, verbose_name='First Name')),
                ('last_name', models.CharField(blank=True, max_length=254, null=True, verbose_name='Last Name')),
                ('gender', models.CharField(blank=True, choices=[('male', 'Male'), ('female', 'Female'), ('other', 'Other')], max_length=15, null=True, verbose_name='Gender')),
                ('preferred_language', models.CharField(blank=True, default='', help_text='Users preferred language', max_length=12, verbose_name='Language')),
                ('is_blocked', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='EmailMergeModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('base_file', models.CharField(max_length=255, verbose_name='File name')),
                ('name', models.CharField(help_text="e.g: 'welcome_email'", max_length=255, verbose_name='Name')),
                ('description', models.TextField(blank=True, help_text='Description of this template.', verbose_name='Description')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('last_updated', models.DateTimeField(auto_now=True)),
                ('subject', models.CharField(blank=True, max_length=255, validators=[sendmail.validators.validate_template_syntax], verbose_name='Subject')),
                ('content', models.TextField(blank=True, validators=[sendmail.validators.validate_template_syntax], verbose_name='Content')),
                ('language', models.CharField(blank=True, default='', help_text='Render template in alternative language', max_length=12, verbose_name='Language')),
                ('default_template', models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translated_templates', to='sendmail.emailmergemodel', verbose_name='Default template')),
                ('extra_recipients', models.ManyToManyField(blank=True, help_text='extra bcc recipients', to='sendmail.emailaddress')),
            ],
            options={
                'verbose_name': 'Email Template',
                'verbose_name_plural': 'Email Templates',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='EmailModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_email', models.CharField(max_length=254, validators=[sendmail.validators.validate_email_with_name], verbose_name='Email From')),
                ('subject', models.CharField(blank=True, max_length=989, verbose_name='Subject')),
                ('message', models.TextField(blank=True, verbose_name='Message')),
                ('html_message', models.TextField(blank=True, verbose_name='HTML Message')),
                ('status', models.PositiveSmallIntegerField(blank=True, choices=[(0, 'sent'), (1, 'failed'), (2, 'queued'), (3, 'requeued')], db_index=True, null=True, verbose_name='Status')),
                ('priority', models.PositiveSmallIntegerField(blank=True, choices=[(0, 'low'), (1, 'medium'), (2, 'high'), (3, 'now')], null=True, verbose_name='Priority')),
                ('created', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('last_updated', models.DateTimeField(auto_now=True, db_index=True)),
                ('scheduled_time', models.DateTimeField(blank=True, db_index=True, help_text='The scheduled sending time', null=True, verbose_name='Scheduled Time')),
                ('expires_at', models.DateTimeField(blank=True, help_text="Email won't be sent after this timestamp", null=True, verbose_name='Expires')),
                ('message_id', models.CharField(editable=False, max_length=255, null=True, verbose_name='Message-ID')),
                ('number_of_retries', models.PositiveIntegerField(blank=True, null=True)),
                ('headers', models.JSONField(blank=True, null=True, verbose_name='Headers')),
                ('context', models.JSONField(blank=True, null=True, verbose_name='Context')),
                ('backend_alias', models.CharField(blank=True, default='', max_length=64, verbose_name='Backend alias')),
                ('template', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='sendmail.emailmergemodel', verbose_name='Email template')),
            ],
            options={
                'verbose_name': 'Email',
                'verbose_name_plural': 'Emails',
            },
        ),
        migrations.CreateModel(
            name='Attachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', models.FileField(upload_to=sendmail.models.attachment.get_upload_path, verbose_name='File')),
                ('name', models.CharField(help_text='The original filename', max_length=255, verbose_name='Name')),
                ('mimetype', models.CharField(blank=True, default='', max_length=255)),
                ('headers', models.JSONField(blank=True, null=True, verbose_name='Headers')),
                ('emails', models.ManyToManyField(related_name='attachments', to='sendmail.emailmodel', verbose_name='Emails')),
            ],
            options={
                'verbose_name': 'Attachment',
                'verbose_name_plural': 'Attachments',
            },
        ),
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField(auto_now_add=True)),
                ('status', models.PositiveSmallIntegerField(choices=[(0, 'sent'), (1, 'failed')], verbose_name='Status')),
                ('exception_type', models.CharField(blank=True, max_length=255, verbose_name='Exception type')),
                ('message', models.TextField(verbose_name='Message')),
                ('email', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='logs', to='sendmail.emailmodel', verbose_name='Email address')),
            ],
            options={
                'verbose_name': 'Log',
                'verbose_name_plural': 'Logs',
            },
        ),
        migrations.CreateModel(
            name='PlaceholderContent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(blank=True, default='', max_length=12)),
                ('placeholder_name', models.CharField(max_length=63, verbose_name='Placeholder name')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(default='', verbose_name='Content')),
                ('base_file', models.CharField(max_length=255, verbose_name='File name')),
                ('emailmerge', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='contents', to='sendmail.emailmergemodel')),
            ],
        ),
        migrations.CreateModel(
            name='Recipient',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('send_type', models.CharField(choices=[('to', 'To'), ('cc', 'Cc'), ('bcc', 'Bcc')], default='to', max_length=12)),
                ('address', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sendmail.emailaddress')),
                ('email', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sendmail.emailmodel')),
            ],
        ),
        migrations.AddField(
            model_name='emailmodel',
            name='recipients',
            field=models.ManyToManyField(related_name='to_emails', through='sendmail.Recipient', to='sendmail.emailaddress'),
        ),
        migrations.AddConstraint(
            model_name='emailmergemodel',
            constraint=models.UniqueConstraint(fields=('name', 'language', 'default_template'), name='unique_emailmerge'),
        ),
        migrations.AddConstraint(
            model_name='placeholdercontent',
            constraint=models.UniqueConstraint(fields=('emailmerge', 'placeholder_name', 'language', 'base_file'), name='unique_placeholder'),
        ),
    ]
